#ifndef POKEPLATINUM_UNK_0207D3B8_H
#define POKEPLATINUM_UNK_0207D3B8_H

#include "struct_defs/struct_0207CDEC.h"
#include "struct_decls/struct_0207D3C0_decl.h"
#include "struct_decls/struct_0207D99C_decl.h"
#include "struct_decls/struct_021C0794_decl.h"

int sub_0207D3B8(void);
UnkStruct_0207D3C0 * sub_0207D3C0(int param0);
void sub_0207D3D8(UnkStruct_0207D3C0 * param0);
void sub_0207D3EC(const UnkStruct_0207D3C0 * param0, UnkStruct_0207D3C0 * param1);
u32 sub_0207D3FC(const UnkStruct_0207D3C0 * param0);
void sub_0207D404(UnkStruct_0207D3C0 * param0, u32 param1);
BOOL sub_0207D55C(UnkStruct_0207D3C0 * param0, u16 param1, u16 param2, u32 param3);
BOOL sub_0207D570(UnkStruct_0207D3C0 * param0, u16 param1, u16 param2, u32 param3);
BOOL sub_0207D60C(UnkStruct_0207D3C0 * param0, u16 param1, u16 param2, u32 param3);
BOOL sub_0207D658(UnkStruct_0207CDEC * param0, u32 param1, u16 param2, u16 param3, u32 param4);
BOOL sub_0207D688(UnkStruct_0207D3C0 * param0, u16 param1, u16 param2, u32 param3);
BOOL sub_0207D69C(UnkStruct_0207D3C0 * param0, u32 param1);
u16 sub_0207D730(UnkStruct_0207D3C0 * param0, u16 param1, u32 param2);
u16 sub_0207D748(UnkStruct_0207CDEC * param0, u32 param1, u16 param2, u32 param3);
void sub_0207D780(UnkStruct_0207CDEC * param0, const u32 param1);
void sub_0207D7CC(UnkStruct_0207CDEC * param0, const u32 param1);
void * sub_0207D824(UnkStruct_0207D3C0 * param0, const u8 * param1, u32 param2);
UnkStruct_0207CDEC * sub_0207D910(UnkStruct_0207D3C0 * param0, u16 param1, u16 param2);
UnkStruct_0207D3C0 * sub_0207D990(UnkStruct_021C0794 * param0);
UnkStruct_0207D99C * sub_0207D99C(u32 param0);
void sub_0207D9B4(UnkStruct_0207D99C * param0, u32 param1, u8 * param2, u8 * param3);
u16 sub_0207D9C4(UnkStruct_0207D99C * param0);
void sub_0207D9C8(UnkStruct_0207D99C * param0, u32 param1, u8 param2, u8 param3);
void sub_0207D9D4(UnkStruct_0207D99C * param0, u16 param1);
void sub_0207D9D8(UnkStruct_0207D99C * param0, u32 param1, u8 * param2, u8 * param3);
u16 sub_0207D9E4(UnkStruct_0207D99C * param0);
u16 sub_0207D9E8(UnkStruct_0207D99C * param0);
u16 sub_0207D9EC(UnkStruct_0207D99C * param0);
void sub_0207D9F0(UnkStruct_0207D99C * param0, u32 param1, u8 param2, u8 param3);
void sub_0207D9F8(UnkStruct_0207D99C * param0);
void sub_0207DA1C(UnkStruct_0207D99C * param0, u16 param1, u16 param2);
void sub_0207DA24(UnkStruct_0207D99C * param0, u16 param1);

#endif // POKEPLATINUM_UNK_0207D3B8_H
